@@ -15,6 +15,7 @@ namespace Symfony\Component\Mercure\Tests;
 
 use Lcobucci\JWT\Signer\Key\InMemory;
 use PHPUnit\Framework\TestCase;
+use Symfony\Component\HttpFoundation\Cookie;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\Mercure\Authorization;
 use Symfony\Component\Mercure\Exception\RuntimeException;
@@ -40,7 +41,7 @@ class AuthorizationTest extends TestCase
             'https://example.com/.well-known/mercure',
             new StaticTokenProvider('foo.bar.baz'),
             function (Update $u): string { return 'dummy'; },
-            new LcobucciFactory('secret', 'hmac.sha256', 3600)
+            new LcobucciFactory('looooooooooooongenoughtestsecret', 'hmac.sha256', 3600)
         ));
 
         $authorization = new Authorization($registry);
@@ -68,12 +69,13 @@ class AuthorizationTest extends TestCase
         ));
 
         $request = Request::create('https://example.com');
-        $authorization = new Authorization($registry, 0);
+        $authorization = new Authorization($registry, 0, Cookie::SAMESITE_LAX);
         $authorization->setCookie($request, ['foo'], ['bar'], ['x-foo' => 'bar']);
 
         $cookie = $request->attributes->get('_mercure_authorization_cookies')[null];
         $this->assertNotNull($cookie->getValue());
         $this->assertSame(0, $cookie->getExpiresTime());
+        $this->assertSame(Cookie::SAMESITE_LAX, $cookie->getSameSite());
     }
 
     public function testClearCookie(): void
@@ -83,7 +85,7 @@ class AuthorizationTest extends TestCase
             new StaticTokenProvider('foo.bar.baz'),
             function (Update $u): string { return 'dummy'; },
             new class() implements TokenFactoryInterface {
-                public function create(array $subscribe = [], array $publish = [], array $additionalClaims = []): string
+                public function create(?array $subscribe = [], ?array $publish = [], array $additionalClaims = []): string
                 {
                     return '';
                 }
@@ -112,7 +114,7 @@ class AuthorizationTest extends TestCase
             $hubUrl,
             new StaticTokenProvider('foo.bar.baz'),
             function (Update $u): string { return 'dummy'; },
-            new LcobucciFactory('secret', 'hmac.sha256', 3600)
+            new LcobucciFactory('looooooooooooongenoughtestsecret', 'hmac.sha256', 3600)
         ));
 
         $authorization = new Authorization($registry);
@@ -144,7 +146,7 @@ class AuthorizationTest extends TestCase
             $hubUrl,
             new StaticTokenProvider('foo.bar.baz'),
             function (Update $u): string { return 'dummy'; },
-            new LcobucciFactory('secret', 'hmac.sha256', 3600)
+            new LcobucciFactory('looooooooooooongenoughtestsecret', 'hmac.sha256', 3600)
         ));
 
         $authorization = new Authorization($registry);
@@ -170,7 +172,7 @@ class AuthorizationTest extends TestCase
             new StaticTokenProvider('foo.bar.baz'),
             function (Update $u): string { return 'dummy'; },
             new class() implements TokenFactoryInterface {
-                public function create(array $subscribe = [], array $publish = [], array $additionalClaims = []): string
+                public function create(?array $subscribe = [], ?array $publish = [], array $additionalClaims = []): string
                 {
                     return '';
                 }
@@ -182,4 +184,28 @@ class AuthorizationTest extends TestCase
         $authorization->setCookie($request);
         $authorization->clearCookie($request);
     }
+
+    public function testSetNullCookieTopics(): void
+    {
+        $tokenFactory = $this->createMock(TokenFactoryInterface::class);
+        $tokenFactory
+            ->expects($this->once())
+            ->method('create')
+            ->with($this->isNull(), $this->isNull(), $this->arrayHasKey('x-foo'))
+        ;
+
+        $registry = new HubRegistry(new MockHub(
+            'https://example.com/.well-known/mercure',
+            new StaticTokenProvider('foo.bar.baz'),
+            function (Update $u): string { return 'dummy'; },
+            $tokenFactory
+        ));
+
+        $request = Request::create('https://example.com');
+        $authorization = new Authorization($registry);
+        $authorization->setCookie($request, null, null, ['x-foo' => 'bar']);
+
+        $cookie = $request->attributes->get('_mercure_authorization_cookies')[null];
+        $this->assertNotNull($cookie->getValue());
+    }
 }
